@@ -566,7 +566,9 @@ class PersonLDAPPersonPart(SchoolToolLDAPObjectPart):
         SchoolToolLDAPObjectPart.__init__(self, *args, **kw)
 
     def oneline(self, t):
-        return t and (u' '.join(t)).strip() or u''
+        if not t:
+            return u''
+        return u' '.join(s.decode('UTF-8') for s in t).strip()
 
     def update(self):
         super(PersonLDAPPersonPart, self).update()
