@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #
 # SchoolTool - common information systems platform for school administration
 # Copyright (c) 2005 Shuttleworth Foundation
@@ -22,10 +23,29 @@ Unit tests for schooltool.ldap.security
 
 import unittest
 import doctest
+from schooltool.ldap.security import PersonLDAPPersonPart
+from schooltool.ldap.security import LDAPPerson
+
+
+class TestPersonLDAPPersonPart(unittest.TestCase):
+
+    def setUp(self):
+        person = LDAPPerson(None, None)
+        self.part = PersonLDAPPersonPart(person)
+
+    def test_oneline(self):
+        line = self.part.oneline(['Bob', 'Marley'])
+        self.assertEqual(line, u'Bob Marley')
+        vejas = [u'Šiaurės', u'Vėjas']
+        # data from LDAP comes UTF-8 encoded
+        vejas = [s.encode('UTF-8') for s in vejas]
+        line = self.part.oneline(vejas)
+        self.assertEqual(line, u'Šiaurės Vėjas')
 
 
 def test_suite():
     return unittest.TestSuite([
+        unittest.makeSuite(TestPersonLDAPPersonPart),
         doctest.DocTestSuite(optionflags=doctest.ELLIPSIS),
         doctest.DocFileSuite('../security.txt', optionflags=doctest.ELLIPSIS),
         ])
